@@ -10,8 +10,8 @@ use strict;
 
 ########################################################
 # Specify version and build-date:
-my $Version = '7.13';
-my $VDate = '07/22/25';
+my $Version = '7.14';
+my $VDate = '01/22/26';
 
 #######################################################
 # Logwatch was originally written by:
@@ -204,7 +204,7 @@ my ($tmp_mailto, $tmp_savefile);
              "s|service=s@" => \@TempServiceList,
              "m|mailto=s"   => \$tmp_mailto,
              "filename=s"   => \$tmp_savefile,
-             "a|archives"   => \$Config{'archives'},
+             "a|archives!"  => \$Config{'archives'},
              "debug=s"      => \$Config{'debug'},
              "r|range=s"    => \$Config{'range'},
              "n|numeric"    => \$Config{'numeric'},
